#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.2.1.4
visibility:             public
id:                     gtk-sni-tray-0.2.1.4-9H4Vlr8SezhIBj99WETlIm
key:                    gtk-sni-tray-0.2.1.4-9H4Vlr8SezhIBj99WETlIm
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/taffybar/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/taffybar/gtk-sni-tray#readme>

category:               System
abi:                    a13e2e5cfed96893a727a01eae0589aa
exposed:                True
exposed-modules:
    StatusNotifier.Icon.Pixbuf StatusNotifier.TransparentWindow
    StatusNotifier.Tray StatusNotifier.Tray.ContextMap

hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.2.1.4
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.2.1.4 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.2.1.4 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.2.1.4-9H4Vlr8SezhIBj99WETlIm
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread atk-bridge-2.0 atspi Xtst Xi
    Xfixes atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-14zrP2ElPyi7I7UEc8EF80
    dbus-menu-0.1.3.4-nIl8CZKaj9J6wxyqtoY7r directory-1.3.8.5
    enclosed-exceptions-1.0.3-JAMZ7NJniZq89V58ZtPXFY filepath-1.4.300.1
    gi-cairo-1.0.30-KvBXKA7Kp6yJ7AxspTj18j
    gi-cairo-connector-0.1.1-GmvBSupoyPM8sKofqC2WCJ
    gi-cairo-render-0.1.2-Kj3foQkl9TH1rrXqbiLLy2
    gi-dbusmenugtk3-0.4.16-Ar7TrOjim3rJoPpn118CXl
    gi-gdk3-3.0.30-LZ6L4dg06uxEc7qUGSgj84
    gi-gdkpixbuf-2.0.32-7QYwAeBe7NEAQ4LiM2475Y
    gi-glib-2.0.30-LmzXQ186UEg90tkBw2C6V9
    gi-gobject-2.0.31-3A9RvIrJNMmKTi9mEMhnXb
    gi-gtk3-3.0.44-L8TX7qBZ6MsFIZhFqqVENc
    gtk-scaling-image-0.1.0.1-HA3vctd5hSlfBZVHbZoi0
    gtk-strut-0.1.4.1-Jz4UVbUS0MVKTVCmTCt4KE
    haskell-gi-0.26.17-LUbnxwr8mnB6jZ9E34J7wT
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-5J7cXR4zP7qIvFH1YUzyfL
    status-notifier-item-0.3.2.16-7zpMRh0IIKyKYHcuwuRdck text-2.0.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-14xtbs5TLc62VD3vL7oXgS unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

